function response = modelTorsion_LVE(measurement,L,w,h,a,b,GInf,ds_pref)

    response.speed = measurement.speed;
    response.time = measurement.time;
    response.angle = measurement.angle;
    response.anglerate = measurement.anglerate;

    %% Divide crosssection in regular grid, compute (X2,X3) centers
    spacing = 20;
    X2 = linspace(-0.5*(w-w/spacing),0.5*(w-w/spacing),spacing);
    X3 = linspace(-0.5*(h-h/spacing),0.5*(h-h/spacing),spacing);
    [X2,X3] = meshgrid(X2,X3);
    
    %% Define twist angle 
%     varphi = response.angle/180*pi/L;
%     varphidot = response.anglerate/180*pi/L;
    varphidot = response.speed/30*pi/L;

    %% Compute deformations
    N = 20;
%     [gamma12,gamma13] = freeTorsionStrainsIsotropic(X2,X3,w,h,varphi,N);
    [gammadot12,gammadot13] = freeTorsionStrainsIsotropic(X2,X3,w,h,varphidot,N);

%     slope_gammadot12 = diff(gammadot12,1,3);
%     slope_gammadot13 = diff(gammadot13,1,3);

    %% Resize arrays
    X2 = repmat(X2,1,1,numel(response.time));
    X3 = repmat(X3,1,1,numel(response.time));
%     varphi = reshape(varphi,1,1,numel(varphi));
%     varphi = repmat(varphi,size(X2,1),size(X2,2),1);
%     varphidot = reshape(varphidot,1,1,numel(varphidot));
%     varphidot = repmat(varphidot,size(X2,1),size(X2,2),1);
    time = reshape(response.time,1,1,[]);
    time = repmat(time,size(X2,1),size(X2,2),1);

    %% Compute material reponse
    Gr = @(t) a*t.^-b+GInf;

    tau12 = zeros(size(X2));
    tau13 = zeros(size(X2));
    for i=2:size(tau12,3)
        t = time(:,:,i);

        ds = t(1,1)/ceil(t(1,1)/ds_pref);
        s = linspace(0,t(1,1),round(t(1,1)/ds)+1);
        s = s(1:end-1)+0.5*ds;

        s = repmat(reshape(s,1,1,[]),size(tau12,1),size(tau12,2),1);

%         [index,frac] = interpolate(time(1,1,:),s(1,1,:));
%         frac = repmat(frac,size(tau12,1),size(tau12,2),1);

%         rate12 = gammadot12(:,:,index)+frac.*slope_gammadot12(:,:,index);
%         rate13 = gammadot13(:,:,index)+frac.*slope_gammadot13(:,:,index);

%         tau12(:,:,i) = sum(Gr(time(:,:,i)-s).*rate12*ds,3);
%         tau13(:,:,i) = sum(Gr(time(:,:,i)-s).*rate13*ds,3);

        rate12 = repmat(gammadot12,1,1,size(s,3));
        rate13 = repmat(gammadot13,1,1,size(s,3));

        tau12(:,:,i) = sum(Gr(time(:,:,i)-s).*rate12*ds,3);
        tau13(:,:,i) = sum(Gr(time(:,:,i)-s).*rate13*ds,3);
    end

    %% Integrate to obtain Torque
    darea = (w*h)/spacing^2;
    response.torque = reshape(sum(sum((X2.*tau13-X3.*tau12)*darea,1),2),size(X2,3),1,1);

end

% function [index,frac] = interpolate(t,s)
% 
%     index = zeros(size(s));
%     for i=2:numel(t)
%         index(~index) = (s(~index)<t(i))*(i-1);
%     end
%     slope = diff(t);
%     frac = (s-t(index))./slope(index);
% 
% end