function response = modelTorsion_NLVE(measurement,L,w,h,G,K,n)

    response.speed = measurement.speed;
    response.time = measurement.time;
    response.angle = response.time*response.speed*6;
    response.anglerate = ones(size(response.time))*response.speed*6; 
%     response.angle = measurement.angle;
%     response.anglerate = measurement.anglerate;

    %% Divide crosssection in regular grid, compute (X2,X3) centers
    spacing = 20;
    X2 = linspace(-0.5*(w-w/spacing),0.5*(w-w/spacing),spacing);
    X3 = linspace(-0.5*(h-h/spacing),0.5*(h-h/spacing),spacing);
    [X2,X3] = meshgrid(X2,X3);
    
    %% Define twist angle 
    varphi = response.angle/180*pi/L;
    varphidot = response.anglerate/180*pi/L;

    %% Resize arrays
    X2 = repmat(X2,1,1,numel(varphi));
    X3 = repmat(X3,1,1,numel(varphi));
    varphi = reshape(varphi,1,1,numel(varphi));
    varphi = repmat(varphi,size(X2,1),size(X2,2),1);
    varphidot = reshape(varphidot,1,1,numel(varphidot));
    varphidot = repmat(varphidot,size(X2,1),size(X2,2),1);

    %% Compute deformations
    N = 20;
    [gamma12,gamma13] = freeTorsionStrainsIsotropic(X2,X3,w,h,varphi,N);
    epsilon12 = 0.5*gamma12;
    epsilon13 = 0.5*gamma13;

    [gammadot12,gammadot13] = freeTorsionStrainsIsotropic(X2,X3,w,h,varphidot,N);
    epsilondot12 = 0.5*gammadot12;
    epsilondot13 = 0.5*gammadot13;

    %% Compute material reponse
    eqshrrate = sqrt(2*(2*epsilondot12.^2+2*epsilondot13.^2));
    eta = K.*eqshrrate.^(n-1);

    tau12 = 2 * G * epsilon12 + 2 * eta .* epsilondot12;
    tau13 = 2 * G * epsilon13 + 2 * eta .* epsilondot13;

    %% Integrate to obtain Torque
    darea = (w*h)/spacing^2;
    response.torque = reshape(sum(sum((X2.*tau13-X3.*tau12)*darea,1),2),size(X2,3),1,1);

end