function [response] = modelTorsion_NLVE_aniso(measurement,L,w,h,G12,G13,K12,K13,n,f)

    response.speed = measurement.speed;
    response.time = measurement.time;

    response.angle = response.time*response.speed*6;
    response.anglerate = ones(size(response.time))*response.speed*6; 

    %% Divide crosssection in regular grid, compute (X2,X3) centers
    spacing = 20;
    X2 = linspace(-0.5*(w-w/spacing),0.5*(w-w/spacing),spacing);
    X3 = linspace(-0.5*(h-h/spacing),0.5*(h-h/spacing),spacing);
    [X2,X3] = meshgrid(X2,X3);
    
    %% Define twist angle 
    varphi = response.angle/180*pi/L;
    varphidot = response.anglerate/180*pi/L;

    %% Resize arrays
    X2 = repmat(X2,1,1,numel(varphi));
    X3 = repmat(X3,1,1,numel(varphi));
    varphi = reshape(varphi,1,1,numel(varphi));
    varphi = repmat(varphi,size(X2,1),size(X2,2),1);
    varphidot = reshape(varphidot,1,1,numel(varphidot));
    varphidot = repmat(varphidot,size(X2,1),size(X2,2),1);

    %% Compute deformations
    N = 20;
    [gamma12,gamma13] = freeTorsionStrainsAnisotropic(X2,X3,w,h,varphi,N,f);
    [gammadot12,gammadot13] = freeTorsionStrainsAnisotropic(X2,X3,w,h,varphidot,N,f);

    %% Compute material reponse
    eqshrrate = sqrt(2*(gammadot12.^2+gammadot13.^2));
    eta12 = K12.*eqshrrate.^(n-1);
    eta13 = K13.*eqshrrate.^(n-1);

    tau12 = G12 * gamma12 + eta12 .* gammadot12;
    tau13 = G13 * gamma13 + eta13 .* gammadot13;

    %% Integrate to obtain Torque
    darea = (w*h)/spacing^2;
    response.torque = reshape(sum(sum((X2.*tau13-X3.*tau12)*darea,1),2),size(X2,3),1,1);

end