function result = computeDeformation(stateUndeformed,stateDeformed,localcs1D,fiber1,fiber2)

    % % Load the meshes
    % fileUndeformed = fullfile(inputFolder,'flat.msh');
    % fileDeformed = fullfile(inputFolder,'formed.msh');
    % if ~exist(fileUndeformed,'file') || ~exist(fileDeformed,'file')
    %     error('Inputfolder should contain "flat.msh" and "formed.msh" files.')
    % end
    % stateUndeformed = loadDeformationState(fileUndeformed);
    % stateDeformed = loadDeformationState(fileDeformed);
    % 
    % % Set-up the fiber directions
    % [~,foldername] = fileparts(inputFolder);
    % [localcs1D,fiber1,fiber2] = getFiberDefinitionByName(foldername);

    % Only compute deformation for elements which occur in both states.
    elementsUndeformed = [stateUndeformed.elementNumbers stateUndeformed.elements];
    elementsDeformed = [stateDeformed.elementNumbers stateDeformed.elements];
    elementsIntersect = intersect(elementsUndeformed,elementsDeformed,'rows','stable');
    
    % We want to compute deformation for all elements in the deformed state
    if ~all(size(elementsDeformed)==size(elementsIntersect)) || any(elementsDeformed~=elementsIntersect,'all')
        error('Intersect state does not match deformed state.')
    end
    elementsIntersect = elementsIntersect(:,2:4);

    % Find the accompanying nodes
    selection = ismember(stateUndeformed.nodeNumbers,elementsIntersect);
    nodesUndeformed = stateUndeformed.nodes(selection,:);
    includedNodes = selection;

    selection = ismember(stateDeformed.nodeNumbers,elementsIntersect);
    nodesDeformed = stateDeformed.nodes(selection,:);

    % Update the node indices in the elements
    inverseIndex(stateDeformed.nodeNumbers) = 1:numel(stateDeformed.nodeNumbers);
    elementsIntersect = reshape(inverseIndex(elementsIntersect),size(elementsIntersect));
    
    % Build meshes
    meshUndeformed = triangulation(elementsIntersect,nodesUndeformed);
    meshDeformed = triangulation(elementsIntersect,nodesDeformed);

    % Compute results
    result.meshRef = meshUndeformed;
    result.mesh = meshDeformed;
    result.includedNodes = includedNodes;
    result.elements = computeElementDeformation(meshUndeformed,meshDeformed,localcs1D,fiber1,fiber2);
    result.nodes = extrapolateToNodes(result.elements,meshDeformed);

end

