function [resultOnNode] = extrapolateToNodes(resultOnElement,mesh)

    % Figure out which elements are connected to each node
    V = vertexAttachments(mesh);
    numE = cellfun(@numel,V);

    attachmentMatrix = zeros(numel(V),max(numE));
    for i = 1:numel(V)
        attachmentMatrix(i,1:numE(i)) = V{i};
    end
    selection = attachmentMatrix~=0;

    % Loop over results and compute mean on each node
    resultNames = fieldnames(resultOnElement);
    for i = 1:numel(resultNames)
        result = resultNames{i};
        if iscell(resultOnElement.(result))
            % Don't apply averaging on cell results
            continue
        end
        if size(resultOnElement.(result),2)==1
            % Average scalar values
            resultOnNode.(result) = zeros(size(attachmentMatrix));
            resultOnNode.(result)(selection) = resultOnElement.(result)(attachmentMatrix(selection));
            resultOnNode.(result) = sum(resultOnNode.(result),2)./numE;
        else
            % Average vector values
            dim = size(resultOnElement.(result),2);
            resultOnNode.(result) = zeros(size(attachmentMatrix,1),size(attachmentMatrix,2),dim);
            for j=1:dim
                tempSelect = false(size(resultOnNode.(result)));
                tempSelect(:,:,j) = selection;
                resultOnNode.(result)(tempSelect) = resultOnElement.(result)(attachmentMatrix(selection),j);
            end
            resultOnNode.(result) = sum(resultOnNode.(result),2)./repmat(numE,1,1,dim);
            resultOnNode.(result) = permute(resultOnNode.(result),[1 3 2]);
        end
        
    end    

end