function state = loadDeformationState(file)

    % input variable "file" needs to have ".msh" extension
    [folder,filename,ext] = fileparts(file);
    if isempty(ext)
        ext = '.msh';
        file = fullfile(folder,[filename ext]);
    end

    % Reads the nodes and elements from the ".msh" file
    [nodes,elements] = readGiDMesh(file);

    % Re-structure the content into a structure
    state.nodeNumbers = nodes(:,1);
    state.nodes = nodes(:,2:4);
    state.elementNumbers = elements(:,1);
    state.elements = elements(:,2:4);

    % Make a "triangulation" object that can be used for visual purposes
    inverseIndex(state.nodeNumbers) = 1:numel(state.nodeNumbers);
    displayElements = reshape(inverseIndex(state.elements),size(state.elements));
    state.displayMesh = triangulation(displayElements,state.nodes);

    % Load the precision data if the file exists
    file = fullfile(folder,[filename '_precision.csv']);
    if exist(file,'file')
        precision = readmatrix(file);
        if size(precision,1)==size(state.nodes,1) && size(precision,2)==4 && all(precision(:,1)==state.nodeNumbers)
            state.precision = precision(:,2:4);
        else
            error(['Could not read file "' filename '_precision.csv"'])
        end
    end

end