clear all;close all;clc

addpath('code')

APC{1} = readtable('rawDataOscillatory/Frequency Sweep APC2B.csv','VariableNamingRule','preserve');
APC{2} = readtable('rawDataOscillatory/Frequency Sweep APC8T.csv','VariableNamingRule','preserve');
APC{3} = readtable('rawDataOscillatory/Frequency Sweep APC9B.csv','VariableNamingRule','preserve');
TC1225{1} = readtable('rawDataOscillatory/Frequency Sweep TC2B.csv','VariableNamingRule','preserve');
TC1225{2} = readtable('rawDataOscillatory/Frequency Sweep TC7B.csv','VariableNamingRule','preserve');
TC1225{3} = readtable('rawDataOscillatory/Frequency Sweep TC8T.csv','VariableNamingRule','preserve');

%%
APC = computeAverage(APC);
TC1225 = computeAverage(TC1225);

%%
figure
x = TC1225.freq;
y = TC1225.storage;
ystd = TC1225.storagestd;
fill([x; flipud(x)],[y-ystd; flipud(y+ystd)],'b','FaceAlpha',0.25,'EdgeColor','none');
hold on
h(1) = loglog(x,y,'-bs');

y = TC1225.loss;
ystd = TC1225.lossstd;
fill([x; flipud(x)],[y-ystd; flipud(y+ystd)],'b','FaceAlpha',0.25,'EdgeColor','none');
h(2) = loglog(x,y,'-bo');

x = APC.freq;
y = APC.storage;
ystd = APC.storagestd;
fill([x; flipud(x)],[y-ystd; flipud(y+ystd)],'r','FaceAlpha',0.25,'EdgeColor','none');
h(3) = loglog(x,y,'-rs');

y = APC.loss;
ystd = APC.lossstd;
fill([x; flipud(x)],[y-ystd; flipud(y+ystd)],'r','FaceAlpha',0.25,'EdgeColor','none');
h(4) = loglog(x,y,'-ro');

%%
set(gca,'XScale','log','YScale','log')
xlabel('Angular frequency [rad/s]')
ylabel('Modulus [MPa]')
legend(h,{'Storage mod. TC1225','Loss mod. TC1225','Storage mod. APC','Loss mod. APC'},'AutoUpdate','off')
axis(10.^[-2 2 -0.5 2.5])
grid on
set(gca,'XTick',10.^[-2 -1 0 1 2],'YTick',10.^[0 1 2])

%% Fix plot looks
fixPlotText();
set(gcf,'Units','centimeters','Position',[10 10 7 6.5],'color','white')

%%
% exportgraphics(gcf,'frequencysweep.pdf','contenttype','vector')

%% Interpolation
omega = 2.^(-5:5);
APC = computeInterpolation(APC,omega);
TC1225 = computeInterpolation(TC1225,omega);

n = loglog(TC1225.freq,TC1225.storage,'kx');
loglog(TC1225.freq,TC1225.loss,'kx');
loglog(APC.freq,APC.storage,'kx');
loglog(APC.freq,APC.loss,'kx');

legend(gca,[h n],{'Storage mod. TC1225','Loss mod. TC1225','Storage mod. APC','Loss mod. APC','Interpolation'},'AutoUpdate','off')

% exportgraphics(gcf,'frequencysweep_interpolated.pdf','contenttype','vector')

%% Relaxation modulus
t = 1./omega(2:end-1);
Gr = @(storage,loss) storage(2:end-1)-0.528*loss(1:end-2)+0.112*loss(2:end-1)+0.0383*loss(3:end);
Gr_APC = Gr(APC.storage,APC.loss);
Gr_TC1225 = Gr(TC1225.storage,TC1225.loss);

clear h
figure
h(1) = loglog(t,Gr_TC1225,'bd');
hold on
h(2) = loglog(t,Gr_APC,'rd');
axis([0.05 20 1 10])
xlabel('Time [s]')
ylabel('Relaxation modulus [MPa]')
legend(h,{'Toray TC1225','Solvay APC'},'Location','EastOutside','AutoUpdate','off')
grid on

set(gca,'XTick',10.^[-1 0 1])

fixPlotText();
set(gcf,'Units','centimeters','Position',[10 10 10.5 6.5],'color','white')

%% Model function 
modelfun = @(b,x) b(1).*x.^(-b(2)) + b(3);
beta0 = [5 0.1 5];

GrFit_APC = fitnlm(t,Gr_APC,modelfun,beta0,'CoefficientNames',{'a','b','GInf'});
GrFit_TC1225 = fitnlm(t,Gr_TC1225,modelfun,beta0,'CoefficientNames',{'a','b','GInf'});

k = loglog(t',predict(GrFit_TC1225,t'),'k--');
loglog(t',predict(GrFit_APC,t'),'k--');

legend([h k],{'Toray TC1225','Solvay APC','Model fit'},'Location','EastOutside')

str = sprintf(['$$a = %0.3f$$' newline '$$b = %0.3f$$' newline '$$G_\\infty = %0.3f$$'],GrFit_TC1225.Coefficients.Estimate);
t(1) = text(2,7,str,'Interpreter','latex','FontSize',9);
str = sprintf(['$$a = %0.3f$$' newline '$$b = %0.3f$$' newline '$$G_\\infty = %0.3f$$'],GrFit_APC.Coefficients.Estimate);
t(2) = text(0.2,2,str,'Interpreter','latex','FontSize',9);

% exportgraphics(gcf,'relaxationmodulus2.pdf','contenttype','vector')

%% Same plot, but on linear scales
f = copyobj(gcf, groot);
a = findobj(f,'type','axes');
set(a,'XScale','linear','YScale','linear')
set(a,'XTick',[0 2 4 6 8 10],'YTick',[0 2 4 6 8 10])
axis(a,[0 10 0 10])
l = findobj(f,'type','legend');
set(l,'location','EastOutside')

t = findobj(f,'type','text');
set(t(1),'Position',[1 1.4 0])
set(t(2),'Position',[2 6 0])

% exportgraphics(gcf,'relaxationmodulus1.pdf','contenttype','vector')

%%
function average = computeAverage(measurement)
    data = zeros(size(measurement{1},1),size(measurement{1},2),numel(measurement));
    for i=1:numel(measurement)
        data(:,:,i) = measurement{i}{:,:};
    end
    average.freq = data(:,2,1);
    average.storage = mean(data(:,3,:),3);
    average.loss = mean(data(:,4,:),3);
    average.storagestd = std(data(:,3,:),[],3);
    average.lossstd = std(data(:,4,:),[],3);
end

%%
function interpolate = computeInterpolation(measurement,interpFreq)
    interpolate.freq = interpFreq;
    interpolate.storage = interp1(measurement.freq,measurement.storage,interpFreq,'linear','extrap');
    interpolate.storagestd = interp1(measurement.freq,measurement.storagestd,interpFreq,'linear','extrap');
    interpolate.loss = interp1(measurement.freq,measurement.loss,interpFreq,'linear','extrap');
    interpolate.lossstd = interp1(measurement.freq,measurement.lossstd,interpFreq,'linear','extrap');
end