clear all;close all;clc

addpath('code')

%% load data
inputFiles = dir('rawDataTransient/*TC1225*_1.csv');
TC1225{1} = readMeasurementTransient(inputFiles);
inputFiles = dir('rawDataTransient/*TC1225*_2.csv');
TC1225{2} = readMeasurementTransient(inputFiles);
inputFiles = dir('rawDataTransient/*TC1225*_3.csv');
TC1225{3} = readMeasurementTransient(inputFiles);

inputFiles = dir('rawDataTransient/*APC*_1.csv');
APC{1} = readMeasurementTransient(inputFiles);
inputFiles = dir('rawDataTransient/*APC*_2.csv');
APC{2} = readMeasurementTransient(inputFiles);
inputFiles = dir('rawDataTransient/*APC*_3.csv');
APC{3} = readMeasurementTransient(inputFiles);

for i=1:3
    TC1225{i} = interpolateMeasurementTransient(TC1225{i},60);
    TC1225{i} = averageMeasurementTransient(TC1225{i});
    APC{i} = interpolateMeasurementTransient(APC{i},60);
    APC{i} = averageMeasurementTransient(APC{i});
end

%% Plot
colors = lines(3);
linestyles = {'-','--','-.'};
linewidth = 1;

f = figure;
t = tiledlayout(f,1,2,'TileSpacing','compact');

a(1) = nexttile(t);
for j=1:3
    measurement = TC1225{j};
    for i=1:1
        xdata = measurement(i).angle;
        ydata = measurement(i).torque;
        ystd = measurement(i).torquestd;
        k(j) = plot(a(1),xdata,ydata,'Color','k','LineStyle',linestyles{j},'LineWidth',linewidth);
        hold on
    end
end
for j=1:3
    measurement = TC1225{j};
    for i=1:numel(measurement)
        xdata = measurement(i).angle;
        ydata = measurement(i).torque;
        ystd = measurement(i).torquestd;
        fill(a(1),[xdata; flipud(xdata)],[ydata-ystd; flipud(ydata+ystd)],colors(i,:),'FaceAlpha',0.25,'EdgeColor','none');
        hold on
        h(i,j) = plot(a(1),xdata,ydata,'Color',colors(i,:),'LineStyle',linestyles{j},'LineWidth',linewidth);
    end
end

a(2) = nexttile(t);
for j=1:3
    measurement = APC{j};
    for i=1:numel(measurement)
        xdata = measurement(i).angle;
        ydata = measurement(i).torque;
        ystd = measurement(i).torquestd;
        fill(a(2),[xdata; flipud(xdata)],[ydata-ystd; flipud(ydata+ystd)],colors(i,:),'FaceAlpha',0.25,'EdgeColor','none');
        hold on
        plot(a(2),xdata,ydata,'Color',colors(i,:),'LineStyle',linestyles{j},'LineWidth',linewidth);
    end
end

xlabel(t,'Rotation angle [°]')
ylabel(t,'Torque [mNm]')
title(a(1),'Toray TC1225')
title(a(2),'Solvay APC')
grid(a,'on')
axis(a,[0 30 0 25])

legendLabels = {'10 rpm','1 rpm','0.1 rpm'};
legendLabels = [legendLabels {'First','Second','Third'}];
lgd = legend([h([3 2 1],1);k'],legendLabels);
lgd.Layout.Tile = 'East';

fixPlotText()
set(f,'Units','centimeters','position',[10 10 17 7],'color','white')

% exportgraphics(gcf,'transienttorsion.pdf','contenttype','vector')