clear all;close all;clc

addpath('code')

%% load data
inputFiles = dir('rawDataTransient/*TC1225*_1.csv');
TC1225 = readMeasurementTransient(inputFiles);
TC1225 = interpolateMeasurementTransient(TC1225,120);
TC1225 = averageMeasurementTransient(TC1225);

inputFiles = dir('rawDataTransient/*APC*_1.csv');
APC = readMeasurementTransient(inputFiles);
APC = interpolateMeasurementTransient(APC,120);
APC = averageMeasurementTransient(APC);

%% Plot Measurements
colors = lines(3);
linewidth = 1;

f = figure;
t = tiledlayout(f,1,2,'TileSpacing','compact');

ax(1) = nexttile(t);
measurement = TC1225;
for i=1:numel(measurement)
    xdata = measurement(i).angle;
    ydata = measurement(i).torque;
    ystd = measurement(i).torquestd;
    fill(ax(1),[xdata; flipud(xdata)],[ydata-ystd; flipud(ydata+ystd)],colors(i,:),'FaceAlpha',0.25,'EdgeColor','none');
    hold on
    g(i) = plot(ax(1),xdata,ydata,'Color',colors(i,:),'LineStyle','-','LineWidth',linewidth);
end
    
ax(2) = nexttile(t);
measurement = APC;
for i=1:numel(measurement)
    xdata = measurement(i).angle;
    ydata = measurement(i).torque;
    ystd = measurement(i).torquestd;
    fill(ax(2),[xdata; flipud(xdata)],[ydata-ystd; flipud(ydata+ystd)],colors(i,:),'FaceAlpha',0.25,'EdgeColor','none');
    hold on
    plot(ax(2),xdata,ydata,'Color',colors(i,:),'LineStyle','-','LineWidth',linewidth);
end

xlabel(t,'Rotation angle [°]')
ylabel(t,'Torque [mNm]')
title(ax(1),'Toray TC1225')
title(ax(2),'Solvay APC')
grid(ax,'on')
axis(ax,[0 30 0 25])

legendLabels = {'10 rpm','1 rpm','0.1 rpm'};
lgd = legend(ax(1),g([3 2 1]),legendLabels,'AutoUpdate','off');
lgd.Layout.Tile = 'East';

fixPlotText()
set(f,'Units','centimeters','position',[10 10 19 7],'color','white')

%% LVE torsion model
L = 48;
w = 10;
h = 10;

a = 1.591;
b = 0.357;
GInf = 3.321;
for i = 1:numel(TC1225)
    ds_pref = max(TC1225(i).time)/250;
    model = modelTorsion_LVE_ideal(TC1225(i),L,w,h,a,b,GInf,ds_pref);
    k(1) = plot(ax(1),model.angle,model.torque,'k-.','LineWidth',linewidth);
end

a = 2.142;
b = 0.138;
GInf = 1.030;
for i = 1:numel(APC)
    ds_pref = max(APC(i).time)/200;
    model = modelTorsion_LVE_ideal(APC(i),L,w,h,a,b,GInf,ds_pref);
    plot(ax(2),model.angle,model.torque,'k-.','LineWidth',linewidth);
end

%% Isotropic NLVE torsion model
range = [5 20];
x0 = ones(1,3);

% x = fminsearch(@(x) fitObjectiveIsotropic(x,TC1225,range),x0);
% G_iT = x(1);
% K_iT = x(2);
% n_iT = x(3);
G_iT = 0.2790;
K_iT = 0.1328;
n_iT = 0.4912;
for i = 1:numel(TC1225)
    model = modelTorsion_NLVE_ideal(TC1225(i),L,w,h,G_iT,K_iT,n_iT);
    k(2) = plot(ax(1),model.angle,model.torque,'k--','LineWidth',linewidth);
end
% str = sprintf(['$$G_{12}$$ = %0.3g' newline '$$G_{13}$$ = %0.3g' newline '$$K_{12}$$ = %0.3g' newline '$$K_{13}$$ = %0.3g' newline 'n = %0.3g'],[G2*factor12 G2*factor13 K*factor12 K*factor13 n]);
% text(ax(1),15,15,str,'Interpreter','latex','FontSize',9);

% x = fminsearch(@(x) fitObjectiveIsotropic(x,APC,range),x0);
% G_iA = x(1)
% K_iA = x(2)
% n_iA = x(3)
G_iA = 0.3129;
K_iA = 0.0844;
n_iA = 0.5501;
for i = 1:numel(APC)
    model = modelTorsion_NLVE_ideal(APC(i),L,w,h,G_iA,K_iA,n_iA);
    plot(ax(2),model.angle,model.torque,'k--','LineWidth',linewidth);
end

%% Anisotropic NLVE torsion model
f_TC1225 = 4.91;
f_APC = 1.84;

% x = fminsearch(@(x) fitObjectiveAnisotropic(x,TC1225,range,f_TC1225),x0);
% G12_aT = x(1)
% G13_aT = x(1)/f_TC1225^2
% K12_aT = x(2)
% K13_aT = x(2)/f_TC1225^2
% n_aT = x(3)
G12_aT = 3.2830;
G13_aT = 0.1362;
K12_aT = 1.5715;
K13_aT = 0.0652;
n_aT = 0.4913;
for i = 1:numel(APC)
    [model] = modelTorsion_NLVE_ideal_aniso(TC1225(i),L,w,h,G12_aT,G13_aT,K12_aT,K13_aT,n_aT,f_TC1225);
    k(3) = plot(ax(1),model.angle,model.torque,'k--','LineWidth',linewidth);
end

% x = fminsearch(@(x) fitObjectiveAnisotropic(x,APC,range,f_APC),x0);
% G12_aA = x(1)
% G13_aA = x(1)/f_APC^2
% K12_aA = x(2)
% K13_aA = x(2)/f_APC^2
% n_aA = x(3)
G12_aA = 0.6778;
G13_aA = 0.2002;
K12_aA = 0.2059;
K13_aA = 0.0608;
n_aA = 0.5502;
for i = 1:numel(APC)
    [model] = modelTorsion_NLVE_ideal_aniso(APC(i),L,w,h,G12_aA,G13_aA,K12_aA,K13_aA,n_aA,f_APC);
    plot(ax(2),model.angle,model.torque,'k--','LineWidth',linewidth);
end

%%
legendLabels = [legendLabels {'LVE model','i-NLVE model','a-NLVE model'}];
lgd = legend(ax(1),[g([3 2 1]) k],legendLabels,'AutoUpdate','off');

%% Export
% exportgraphics(gcf,'torsionmodels.pdf','contenttype','vector')