clear all;close all;clc

addpath('code')

APC{1} = readtable('rawDataOscillatory/Waveform APC7B 001.csv','VariableNamingRule','preserve');
APC{2} = readtable('rawDataOscillatory/Waveform APC7B 01.csv','VariableNamingRule','preserve');
APC{3} = readtable('rawDataOscillatory/Waveform APC7B 1.csv','VariableNamingRule','preserve');
APC{4} = readtable('rawDataOscillatory/Waveform APC7B 0001.csv','VariableNamingRule','preserve');
TC1225{1} = readtable('rawDataOscillatory/Waveform TC8B 001.csv','VariableNamingRule','preserve');
TC1225{2} = readtable('rawDataOscillatory/Waveform TC8B 01.csv','VariableNamingRule','preserve');
TC1225{3} = readtable('rawDataOscillatory/Waveform TC8B 1.csv','VariableNamingRule','preserve');
TC1225{4} = readtable('rawDataOscillatory/Waveform TC8B 0001.csv','VariableNamingRule','preserve');

%% 
for i=1:3
    [APC{i}] = shiftByTorque(APC{i});
    [TC1225{i}] = shiftByTorque(TC1225{i});
end

%%
color = {'r','g','b','m'};
figure
for i =1:3
    x = APC{i}{:,1};
    x = x/pi;
    y = APC{i}{:,2};
    y = y/max(y);
    h(i) = plot(x,y,'-','Color',color{i});
    hold on

    x = TC1225{i}{:,1};
    x = x/pi;
    y = TC1225{i}{:,2};
    y = y/max(y);
    y = y-0.25;
    k(i) = plot(x,y,'-','Color',color{i});
end

x = linspace(0,pi,100);
m = plot(x/pi,sin(x),'k--');
plot(x/pi,sin(x)-0.25,'k--')
xlabel('Period time [s]','Interpreter','latex','FontSize',10)
ylabel('Normalized Torque [-]','Interpreter','latex','FontSize',10)
axis([0 1 -0.25 1])

set(gca,'XTick',[0 0.5 1],'XTickLabel',{'0','0.5\pi','\pi'})
set(gca,'YTick',[])
% legend([m h],{'sin(x)','0.01\%','0.1\%','1\%','0.001\%'},'Location','South','Interpreter','latex','FontSize',10)
legend([m h],{'sin(x)','0.01\%','0.1\%','1\%'},'Location','South','Interpreter','latex','FontSize',10)
text(0.5,0.9,'APC','HorizontalAlignment','center','Interpreter','latex','FontSize',10)
text(0.5,0.85-0.25,'TC1225','HorizontalAlignment','center','Interpreter','latex','FontSize',10)
set(gcf,'Units','centimeters','Position',[10 10 7 6.5],'color','white')

% exportgraphics(gcf,'waveform.pdf','contenttype','vector')

%% Functions
function [data] = shiftByTorque(data)
    torque = data{:,2};
    switchPoint = find(diff(torque<0)<0);
    fraction = abs(torque(switchPoint))/(torque(switchPoint+1)-torque(switchPoint));

    time = data{:,1};
    dtime = diff(time);
    shift = time(switchPoint)+fraction*dtime(switchPoint);
    time = time-shift;

    data{:,1} = time;

    selection = data{:,1}<0;
    period = max(data{:,1})-min(data{:,1});
    part1 = data(~selection,:);
    part2 = data(selection,:);
    part2{:,1} = part2{:,1}+period;

    data = [part1;part2(2:end,:)];
end